#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef HAVE_LIBZ
#undef ENABLE_LIBGPA
#undef USE_GNOME_FONT
